from __future__ import annotations


AQUALINK_API_KEY = "EOOEMOW4YR6QNB07"

<<<<<<< HEAD
AQUALINK_LOGIN_URL = "https://support.iaqualink.com/users/sign_in.json"
AQUALINK_DEVICES_URL = "https://support.iaqualink.com/devices.json"
AQUALINK_SESSION_URL = (
    "https://iaqualink-api.realtime.io/v1/mobile/session.json"
)
=======
AQUALINK_LOGIN_URL = "https://prod.zodiac-io.com/users/v1/login"
AQUALINK_DEVICES_URL = "https://r-api.iaqualink.net/devices.json"
AQUALINK_SESSION_URL = "https://p-api.iaqualink.net/v1/mobile/session.json"
>>>>>>> 89120a9... [const] Update API endpoint URLs

AQUALINK_TEMP_CELSIUS_LOW = 1
AQUALINK_TEMP_CELSIUS_HIGH = 40
AQUALINK_TEMP_FAHRENHEIT_LOW = 32
AQUALINK_TEMP_FAHRENHEIT_HIGH = 104
